View source: R/GetCitationFile.R
| GetCitationFile | R Documentation |
Get citation files
GetCitationFile(
filetype = c("ris", "BibText"),
folder = getwd(),
overwrite = F
)
filetype |
Type of bibliographic file can be either |
folder |
Folder where to save the file. Defaults to |
overwrite |
Boolean. Whether to overwrite namesake files in the target folder. |
Copies the selected type of bibliographic file to the working folder.
GetCitationFile('ris') # to get the .ris file in the working folder
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.